#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-run
version:              0.2.4
visibility:           public
id:                   network-run-0.2.4-IH6gwCwPJQ48q0cXaqrCYL
key:                  network-run-0.2.4-IH6gwCwPJQ48q0cXaqrCYL
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Simple network runner library
description:          Simple functions to run network clients and servers.
category:             Network
abi:                  2da473d3c1355325140c9b4f4124d4ca
exposed:              True
exposed-modules:      Network.Run.TCP Network.Run.UDP
hidden-modules:       Network.Run.Core
import-dirs:          /usr/lib/ghc-8.10.5/site-local/network-run-0.2.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/network-run-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/network-run-0.2.4
hs-libraries:         HSnetwork-run-0.2.4-IH6gwCwPJQ48q0cXaqrCYL
depends:
    base-4.14.2.0 bytestring-0.10.12.0
    network-3.1.2.2-5EE9GqQpTmvH0oBl8byO4M

haddock-interfaces:   /usr/share/doc/haskell-network-run/html/network-run.haddock
haddock-html:         /usr/share/doc/haskell-network-run/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

